@@ -1,7 +1,7 @@
 
 import textwrap
 import subprocess
-from mock import Mock
+from unittest.mock import Mock
 
 import pytest
 
